@extends('cms::admin.layouts.app')
@php

    /**
     * @var \Illuminate\Support\ViewErrorBag $errors
     *
    */

@endphp
@section('content')
    <form action="{{$formRoute}}" method="post"
          @submit="validateBeforeSubmit">

        @include('erp::components.save')
        @csrf
        @method($formMethod)
        <div class="card card-body">

            @component('cms::components.select2')
                @slot('key', 'provider_id')
                @slot('placeholder', trans('erp::erp.provider_id'))
                @slot('value', old('provider_id', $delivery->provider_id?? null))
                @slot('validate', 'required')
                @slot('options', $providers)
            @endcomponent
            @component('cms::components.input')
                @slot('key', 'delivery_number')
                @slot('placeholder', trans('erp::erp.delivery_number'))
                @slot('value', old('delivery_number', $delivery->delivery_number?? null))
            @endcomponent

            <div class="row">
                <div class="col-12 col-lg-5">
                    @component('cms::components.input')
                        @slot('key', 'price_national_currency')
                        @slot('type', 'number')
                        @slot('placeholder', trans('erp::erp.price_national_currency'))
                        @slot('value', old('price_national_currency', $delivery->price_national_currency?? null))
                        @slot('attributes', ['step' => '0.01'])
                    @endcomponent
                </div>
                <div class="col-12 col-lg-5">
                    @component('cms::components.input')
                        @slot('key', 'price_in_currency')
                        @slot('type', 'number')
                        @slot('placeholder', trans('erp::erp.price_in_currency'))
                        @slot('value', old('price_in_currency', $delivery->price_in_currency?? null))
                        @slot('attributes', ['step' => '0.01'])
                    @endcomponent
                </div>
                <div class="col-12 col-lg">
                    @component('cms::components.select2')
                        @slot('key', 'currency')
                        @slot('placeholder', trans('erp::erp.currency'))
                        @slot('value', old('currency', $delivery->currency?? null))
                        @slot('options', selectCurrency())
                    @endcomponent
                </div>
            </div>
            <div class="row">
                <div class="col-12 col-lg-6">
                    @component('cms::components.picker')
                        @slot('key', 'delivery_date')
                        @slot('placeholder', trans('erp::erp.delivery_date'))
                        @slot('value', old('delivery_date', $delivery->delivery_date?? \Illuminate\Support\Carbon::now()->format('d.m.Y')))
                        @slot('validate', 'required')
                    @endcomponent
                </div>
                <div class="col-12 col-lg-6">
                    @component('cms::components.picker')
                        @slot('key', 'payment_deadline')
                        @slot('placeholder', trans('erp::erp.payment_deadline'))
                        @slot('value', old('delivery_date', $delivery->payment_deadline?? \Illuminate\Support\Carbon::now()->format('d.m.Y')))
                        @slot('validate', 'required')
                    @endcomponent
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                <h3 class="card-title">@lang('erp::erp.delivery_items')</h3>
            </div>
            <div class="car-body">
                <delivery-items :delivery-items='@json(old('delivery_items', $delivery->delivery_items?? []))'
                                :validate-errors="errors"
                                :delivery-id='{{old('provider_id', $delivery->id?? 'null')}}'
                                :validation-errors='@json($errors->getMessages())'
                                products-query-url="{{route('cms.api.v1.products.query')}}"
                                delete-item-url="{{route('cms.api.v1.deliveries.items.delete')}}"></delivery-items>
            </div>
        </div>
{{--        <div class="card">--}}
{{--            <div class="card-header">--}}
{{--                <h5 class="card-title">@lang('erp::erp.delivery_transactions')</h5>--}}
{{--            </div>--}}
{{--            <div class="car-body">--}}
{{--                <delivery-payments--}}
{{--                    :transactions='@json(old('delivery_transactions', $delivery->delivery_transactions?? []))'--}}
{{--                ></delivery-payments>--}}
{{--            </div>--}}
{{--        </div>--}}
    </form>
@endsection
@push('vue.components')
    <script src="{{mixErp('js/app.js')}}"></script>
@endpush
